@@ -4,13 +4,22 @@
 #' 
 #' @param x character; taxons to query.
 #' @param db character; database to query. either \code{ncbi}, \code{itis}, 
-#'    \code{eol}, or \code{tropicos}
+#'    \code{eol}, \code{col} or \code{tropicos}.
 #' @param id character; identifiers, returned by \code{\link[taxize]{get_tsn}}, 
 #'    \code{\link[taxize]{get_uid}}, \code{\link[taxize]{get_eolid}}, 
-#'    \code{\link[taxize]{get_colid}}, or \code{\link[taxize]{get_tpsid}}
+#'    \code{\link[taxize]{get_colid}}, or \code{\link[taxize]{get_tpsid}}.
 #' @param ... Other arguments passed to \code{\link[taxize]{get_tsn}}, 
 #'    \code{\link[taxize]{get_uid}}, \code{\link[taxize]{get_eolid}}, 
 #'    \code{\link[taxize]{get_colid}}, or \code{\link[taxize]{get_tpsid}}.
+#' @param start The first record to return. If omitted, the results are returned 
+#' 		from the first record (start=0). This is useful if the total number of 
+#' 		results is larger than the maximum number of results returned by a single 
+#' 		Web service query (currently the maximum number of results returned by a 
+#' 		single query is 500 for terse queries and 50 for full queries).
+#' @param checklist character; The year of the checklist to query, if you want a specific 
+#' 		year's checklist instead of the lastest as default (numeric).
+#' @param key Your API key; loads from .Rprofile.
+#' @param callopts Further args passed on to httr::GET.
 #' 
 #' @return A named list of data.frames with the taxonomic classifcation of 
 #'    every supplied taxa.
@@ -99,12 +108,13 @@ classification.tsn <- function(id, ...)
     } else {
     	out <- getfullhierarchyfromtsn(x, ...)
     	# remove overhang
-    	out <- out[1:which(out$tsn == x), c('rankName', 'taxonName', 'tsn')]
+    	out <- out[1:which(out$tsn == x), c('taxonName', 'rankName')]
+      names(out) <- c('name', 'rank')
     	return(out)
     }
   }
   out <- lapply(id, fun)
-#   names(out) <- id
+  attr(out, 'db') <- 'itis'
   return(out)
 }
 
@@ -123,9 +133,8 @@ classification.uid <- function(id, ...) {
       searchurl <- paste(baseurl, ID, sep = "&")
       tt <- getURL(searchurl)
       ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
-      out <- data.frame(ScientificName = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/ScientificName", xmlValue), 
-                        Rank = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/Rank", xmlValue), 
-                        UID = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/TaxId", xmlValue),
+      out <- data.frame(name = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/ScientificName", xmlValue), 
+                        rank = xpathSApply(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/Rank", xmlValue),
                         stringsAsFactors = FALSE)
       out <- rbind(out, c(xpathSApply(ttp, "//TaxaSet/Taxon/ScientificName", xmlValue),
         xpathSApply(ttp, "//TaxaSet/Taxon/Rank", xmlValue), 
@@ -137,7 +146,7 @@ classification.uid <- function(id, ...) {
     return(out)
   }
   out <- lapply(id, fun)
-#   names(out) <- id
+  attr(out, 'db') <- 'ncbi'
   return(out)
 }
 
@@ -145,15 +154,27 @@ classification.uid <- function(id, ...) {
 #' @method classification eolid
 #' @export
 #' @rdname classification
-classification.eolid <- function(id, ...) {
+classification.eolid <- function(id, key = NULL, callopts = list(), ...) {
+  common_names = NULL
   fun <- function(x){
-    # return NA if NA is supplied
-    if(is.na(x)){
-      tmp <- NA
+    if(is.na(x)){ 
+      out <- NA
     } else {
-      tmp <- eol_hierarchy(taxonid=x, ...)
+      url = 'http://www.eol.org/api/hierarchy_entries/1.0/'
+      key <- getkey(key, "eolApiKey")
+      urlget <- paste(url, x, '.json', sep="")
+      args <- compact(list(common_names=common_names, synonyms=synonyms))
+      tt <- GET(urlget, query=args, callopts)
+      stop_for_status(tt)
+      res <- content(tt)
+      if(length(res$ancestors)==0){
+        return(sprintf("No hierarchy information for %s", x))
+      } else {
+        out <- do.call(rbind.fill, lapply(res$ancestors, data.frame))[,c('scientificName','taxonRank')]
+        names(out) <- c('name', 'rank')
+        return(out)
+      }
     }
-    return(tmp)
   }
   out <- lapply(id, fun)
 #   names(out) <- id
@@ -163,18 +184,36 @@ classification.eolid <- function(id, ...) {
 #' @method classification colid
 #' @export
 #' @rdname classification
-classification.colid <- function(id, ...) {
+classification.colid <- function(id, start = NULL, checklist = NULL, ...) {
   fun <- function(x){
     # return NA if NA is supplied
     if(is.na(x)){
-      tmp <- NA
+      out <- NA
     } else {
-      tmp <- col_classification(id=x, ...)[[1]]
+      url <- "http://www.catalogueoflife.org/col/webservice"
+      if(!is.null(checklist)){
+        cc <- match.arg(checklist, choices = c(2012, 2011, 2010, 2009, 2008, 2007))
+        if (cc %in% c(2012, 2011, 2010)) {
+          url <- gsub("col", paste("annual-checklist/", cc, sep = ""), url)
+        } else {
+          url <- "http://webservice.catalogueoflife.org/annual-checklist/year/search.php"
+          url <- gsub("year", cc, url)
+        }
+      }
+        
+      args <- compact(list(id = x, response = "full", start = start))
+      out <- getForm(url, .params = args)
+      tt <- xmlParse(out)
+      
+      out <- data.frame(name = xpathSApply(tt, "//classification//name", xmlValue),
+                        rank = xpathSApply(tt, "//classification//rank", xmlValue),
+                        stringsAsFactors = FALSE)
     }
-    return(tmp)
+    return(out)
   }
   out <- lapply(id, fun)
-#   names(out) <- id
+  names(out) <- id
+  attr(out, 'db') <- 'col'
   return(out)
 }
 
@@ -182,18 +221,28 @@ classification.colid <- function(id, ...) {
 #' @method classification tpsid
 #' @export
 #' @rdname classification
-classification.tpsid <- function(id, ...) {
+classification.tpsid <- function(id, key = NULL, callopts = list(), ...) {
   fun <- function(x){
-    # return NA if NA is supplied
-    if(is.na(x)){
-      tmp <- NA
+    if(is.na(x)) {
+      out <- NA
     } else {
-      tmp <- tp_classification(id=x, ...)[[1]]
+      url <- sprintf('http://services.tropicos.org/Name/%s/HigherTaxa', x)
+      key <- getkey(key, "tropicosApiKey")
+      args <- compact(list(format='json', apikey=key))
+      tt <- GET(url, query = args, callopts)
+      stop_for_status(tt)
+      out <- content(tt)
+      if(names(out[[1]])[[1]] == "Error"){ 
+        out <- data.frame(ScientificName=NA, Rank=NA) 
+      } else {
+        out <- do.call(rbind.fill, lapply(out, data.frame))[,c('ScientificName','Rank')]
+      }
+      names(out) <- c('name', 'rank')
     }
-    return(tmp)
+    return(out)
   }
   out <- lapply(id, fun)
-#   names(out) <- id
+  names(out) <- id
   return(out)
 }
 
@@ -209,9 +258,9 @@ classification.ids <- function(id, ...)
       out <- NA
     } else {
       out <- classification(x, ...)
-      return(out)
     }
+    return(out)
   }
-  tmp <- lapply(id, fun)
-  return( tmp )
+  out <- lapply(id, fun)
+  return(out)
 }
\ No newline at end of file
