@@ -65,7 +65,7 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
         names(out) <- get
       } else {
         tt <- classification(tsn, ...)[[1]]
-        out <- as.character(tt[tolower(tt$rankName) %in% tolower(get), "taxonName"])
+        out <- as.character(tt[tolower(tt$rank) %in% tolower(get), "name"])
         if(length(out) == 0)
           out <- data.frame(t(rep(NA, length(get))))
         out <- data.frame(t(out), stringsAsFactors = FALSE)
@@ -83,7 +83,7 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
         names(out) <- get
       } else {
   			hierarchy <- classification(uid, ...)[[1]]
-  			match <- hierarchy$ScientificName[match(tolower(get), tolower(hierarchy$Rank))]
+  			match <- hierarchy$name[match(tolower(get), tolower(hierarchy$rank))]
         out <- data.frame(t(match), stringsAsFactors=FALSE)
         names(out) <- get
   		}
@@ -99,7 +99,7 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
         match_uid <- rep(NA, length(get))
       } else {
         hierarchy <- classification(uid, ...)[[1]]
-        match_uid <- hierarchy$ScientificName[match(tolower(get), tolower(hierarchy$Rank))]
+        match_uid <- hierarchy$name[match(tolower(get), tolower(hierarchy$rank))]
       }
       # itis
       tsn <- get_tsn(query, searchtype="sciname", verbose = verbose, ...)
@@ -109,7 +109,7 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
         match_tsn <- rep(NA, length(get))
       } else {
         tt <- classification(tsn)[[1]]
-        match_tsn <- tt$taxonName[match(tolower(get), tolower(tt$rankName))]
+        match_tsn <- tt$name[match(tolower(get), tolower(tt$rank))]
       }
       match_both <- ifelse(is.na(match_uid), match_tsn, match_uid)
       out <- data.frame(t(match_both), stringsAsFactors = FALSE)
